@@ -54,28 +54,28 @@ MainWindow::MainWindow(QString file) :
 	QAction *editListAct = new QAction(tr("Make List"), this);
     connect(editListAct, SIGNAL(triggered()), this, SLOT(on_action_edit_list()));
 
-	QAction *addItemAct = new QAction(QIcon("/usr/share/icons/hicolor/64x64/apps/shopper/add.png"),
+	QAction *addItemAct = new QAction(QIcon("/opt/usr/share/icons/hicolor/64x64/apps/shopper/add.png"),
 									  tr("Add Item"), this);
     addItemAct->setStatusTip(tr("Add an item to the list"));
     connect(addItemAct, SIGNAL(triggered()), this, SLOT(on_action_add_item()));
 
-	QAction *manageCatAct = new QAction(QIcon("/usr/share/icons/hicolor/64x64/apps/shopper/categories.png"),
+	QAction *manageCatAct = new QAction(QIcon("/opt/usr/share/icons/hicolor/64x64/apps/shopper/categories.png"),
 										tr("Manage Categories"), this);
     manageCatAct->setStatusTip(tr("Manage the list of categories"));
     connect(manageCatAct, SIGNAL(triggered()), this, SLOT(on_action_manage_category()));
 
 	// Mode switch Actions
-	QAction *fullListAct = new QAction(QIcon("/usr/share/icons/hicolor/64x64/apps/shopper/full-list.png"),
+	QAction *fullListAct = new QAction(QIcon("/opt/usr/share/icons/hicolor/64x64/apps/shopper/full-list.png"),
 									   tr("Out Shopping: Full List"), this);
     fullListAct->setStatusTip(tr("Show the full list (items in the basket will be visible and ticked)"));
     connect(fullListAct, SIGNAL(triggered()), this, SLOT(on_action_fullList()));
 
-	QAction *whatsLeftAct = new QAction(QIcon("/usr/share/icons/hicolor/64x64/apps/shopper/whats-left.png"),
+	QAction *whatsLeftAct = new QAction(QIcon("/opt/usr/share/icons/hicolor/64x64/apps/shopper/whats-left.png"),
 										tr("Out Shopping: What's Left"), this);
     whatsLeftAct->setStatusTip(tr("Show what's left to get"));
     connect(whatsLeftAct, SIGNAL(triggered()), this, SLOT(on_action_whatsLeft()));
 
-	QAction *makingListAct = new QAction(QIcon("/usr/share/icons/hicolor/64x64/apps/shopper/making-list.png"),
+	QAction *makingListAct = new QAction(QIcon("/opt/usr/share/icons/hicolor/64x64/apps/shopper/making-list.png"),
 										 tr("Making List"), this);
     makingListAct->setStatusTip(tr("Pick items to get when you go shopping"));
     connect(makingListAct, SIGNAL(triggered()), this, SLOT(on_action_makingList()));
@@ -87,17 +87,17 @@ MainWindow::MainWindow(QString file) :
     connect(prefsAct, SIGNAL(triggered()), this, SLOT(on_action_preferences()));
 
 	QAction *aboutAct = new QAction(qApp->style()->standardIcon(QStyle::SP_MessageBoxInformation),
-									tr("About..."), this);
+									tr("About / Help"), this);
     aboutAct->setStatusTip(tr("About Shopper..."));
     connect(aboutAct, SIGNAL(triggered()), this, SLOT(on_action_about()));
 
 	// Navigation Actions
-	nextAct = new QAction(QIcon("/usr/share/icons/hicolor/26x26/apps/shopper/right-arrow-red.png"),
+	nextAct = new QAction(QIcon("/opt/usr/share/icons/hicolor/26x26/apps/shopper/right-arrow-red.png"),
 						  tr("Next Category"), this);
     nextAct->setStatusTip(tr("View the next category"));
     connect(nextAct, SIGNAL(triggered()), this, SLOT(on_action_next()));
 	
-	QAction *prevAct = new QAction(QIcon("/usr/share/icons/hicolor/26x26/apps/shopper/left-arrow-red.png"),
+	QAction *prevAct = new QAction(QIcon("/opt/usr/share/icons/hicolor/26x26/apps/shopper/left-arrow-red.png"),
 								   tr("Prev Category"), this);
     prevAct->setStatusTip(tr("View the previous category"));
     connect(prevAct, SIGNAL(triggered()), this, SLOT(on_action_prev()));
@@ -134,7 +134,7 @@ MainWindow::MainWindow(QString file) :
     addToolBar(Qt::BottomToolBarArea, navBar);
 	addToolBar(Qt::BottomToolBarArea, editBar);
 
-	QIcon shopper_icon("/usr/share/icons/hicolor/64x64/apps/shopper/shopper.png");
+	QIcon shopper_icon("/opt/usr/share/icons/hicolor/64x64/apps/shopper/shopper.png");
 	setWindowIcon(shopper_icon);
 
 	// Prepare our Settings
@@ -251,7 +251,8 @@ void MainWindow::on_action_about()
 						  " was written by David Greaves (lbt). "
 						  "It is Free Software and licensed under the GPL.<br>"
 						  "I hope you enjoy using it.<br>"
-						  "Please let me know of any problems or suggestions at http://tinyurl.com/shopper-bugs"));
+						  "<a href='http://shopper.garage.maemo.org/help.html'>Help can be found online</a><br>"
+						  "Please let me know of any problems or suggestions at <a href='http://tinyurl.com/shopper-bugs'>the bug page</a>"));
 }
 
 void MainWindow::readSettings()
@@ -350,29 +351,42 @@ void MainWindow::on_action_file_new()
 	if (mylist)
 		on_action_file_save();
 	filename="";
-	create_list_view(new Shopper::List(
-		QString(
-			"<list name='Supermarket' state='0'>"
-			"<category name='Aisle 1 - Dairy'>"
-			"<item desc='A left -> right stroke on an item will mark it.' note='' wanted='1' bought='0'/>"
-			"<item desc='Or right -> left. A bit like crossing it off.' note='' wanted='1' bought='0'/>"
-			"<item desc='Stroke left -> right -> left (a scribble) to edit items.' note='' wanted='1' bought='0'/>"
-			"<item desc='To delete this help edit each of these items' note='' wanted='1' bought='0'/>"
-			"<item desc='You can also ... ' note='have notes which can be cleared' wanted='1' bought='0'/>"
-			"</category>"
-			"<category name='Frozen'>"
-			"<item desc='Peas' note='' wanted='1' bought='0'/>"
-			"<item desc='Prawns' note='' wanted='1' bought='0'/>"
-			"</category>"
-			"<category name='Veg'>"
-			"<item desc='Potatoes' note='' wanted='0' bought='0'/>"
-			"<item desc='Brocolli' note='' wanted='1' bought='0'/>"
-			"</category>"
-			"<category name='Shoes'>"
-			"<item desc='Versace' note='For Tracy' wanted='0' bought='0'/>"
-			"</category>"
-			"</list>"
-			)));
+	QSettings settings;
+	if (settings.contains("data/DoneFirstNew")) {
+		create_list_view(new Shopper::List(
+			 QString(
+				 "<list name='Supermarket' state='0'>"
+				 "<category name='Aisle 1'>"
+				 "<item desc='First Item' note='' wanted='1' bought='0'/>"
+				 "</category>"
+				 "</list>"
+				 )));
+	} else {
+		settings.setValue("data/DoneFirstNew", true);
+		create_list_view(new Shopper::List(
+			 QString(
+				 "<list name='Supermarket' state='0'>"
+				 "<category name='Aisle 1 - Dairy'>"
+				 "<item desc='A left -> right stroke on an item will mark it.' note='' wanted='1' bought='0'/>"
+				 "<item desc='Or right -> left. A bit like crossing it off.' note='' wanted='1' bought='0'/>"
+				 "<item desc='Stroke left -> right -> left (a scribble) to edit items.' note='' wanted='1' bought='0'/>"
+				 "<item desc='To delete this help edit each of these items' note='' wanted='1' bought='0'/>"
+				 "<item desc='You can also ... ' note='have notes which can be cleared' wanted='1' bought='0'/>"
+				 "</category>"
+				 "<category name='Frozen'>"
+				 "<item desc='Peas' note='' wanted='1' bought='0'/>"
+				 "<item desc='Prawns' note='' wanted='1' bought='0'/>"
+				 "</category>"
+				 "<category name='Veg'>"
+				 "<item desc='Potatoes' note='' wanted='0' bought='0'/>"
+				 "<item desc='Brocolli' note='' wanted='1' bought='0'/>"
+				 "</category>"
+				 "<category name='Shoes'>"
+				 "<item desc='Versace' note='For Tracy' wanted='0' bought='0'/>"
+				 "</category>"
+				 "</list>"
+				 )));
+	}
 }
 void MainWindow::on_action_file_open()
 {
